import { Configuration, PluginHandler, PluginPromises, ServicePromisesState, Services } from '../type';
/**
 * Dummy plugin implementing a test hook.
 */
export default class Dummy implements PluginHandler {
    /**
     * Loads dummy service.
     * @param state - Application state.
     * @param state.services - Plugin services.
     *
     * @returns A mapping to promises which correspond to the plugin specific
     * continues services.
     */
    static loadService(this: void, { services }: ServicePromisesState): Promise<PluginPromises>;
    /**
     * Asynchronous mock test method.
     * @param state - Application state.
     * @param state.services - Plugin services.
     * @param state.services.dummy - Plugin service.
     *
     * @returns A promise resolving to nothing.
     */
    static test(this: void, { services: { dummy } }: ServicePromisesState<undefined, Configuration, Services<{
        dummy: {
            hookCalled: boolean;
        };
    }>>): Promise<void>;
    /**
     * Synchronous mock test method.
     * @param state - Application state.
     * @param state.services - Plugin services.
     * @param state.services.dummy - Plugin service.
     *
     * @returns Nothing.
     */
    static testSynchronous(this: void, { services: { dummy } }: ServicePromisesState<undefined, Configuration, Services<{
        dummy: {
            synchronousHookCalled: boolean;
        };
    }>>): void;
}
